@@ -1,7 +1,7 @@
 use {
     crate::{rpc_request, rpc_response},
     safecoin_faucet::faucet::FaucetError,
-    solana_sdk::{
+    safecoin_sdk::{
         signature::SignerError, transaction::TransactionError, transport::TransportError,
     },
     std::io,
