@@ -1,7 +1,7 @@
 use {
     crate::rpc_filter::RpcFilterType,
     safecoin_account_decoder::{UiAccountEncoding, UiDataSliceConfig},
-    solana_sdk::{
+    safecoin_sdk::{
         clock::{Epoch, Slot},
         commitment_config::{CommitmentConfig, CommitmentLevel},
     },
@@ -21,6 +21,7 @@ pub struct RpcSendTransactionConfig {
     pub skip_preflight: bool,
     pub preflight_commitment: Option<CommitmentLevel>,
     pub encoding: Option<UiTransactionEncoding>,
+    pub max_retries: Option<usize>,
 }
 
 #[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
@@ -116,6 +117,15 @@ pub struct RpcLargestAccountsConfig {
     pub filter: Option<RpcLargestAccountsFilter>,
 }
 
+#[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct RpcSupplyConfig {
+    #[serde(flatten)]
+    pub commitment: Option<CommitmentConfig>,
+    #[serde(default)]
+    pub exclude_non_circulating_accounts_list: bool,
+}
+
 #[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct RpcEpochConfig {
@@ -174,7 +184,7 @@ pub struct RpcSignatureSubscribeConfig {
 
 #[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
-pub struct RpcGetConfirmedSignaturesForAddress2Config {
+pub struct RpcSignaturesForAddressConfig {
     pub before: Option<String>, // Signature as base-58 string
     pub until: Option<String>,  // Signature as base-58 string
     pub limit: Option<usize>,
@@ -196,6 +206,17 @@ impl<T: EncodingConfig + Default + Copy> RpcEncodingConfigWrapper<T> {
             RpcEncodingConfigWrapper::Current(config) => config.unwrap_or_default(),
         }
     }
+
+    pub fn convert<U: EncodingConfig + From<T>>(&self) -> RpcEncodingConfigWrapper<U> {
+        match self {
+            RpcEncodingConfigWrapper::Deprecated(encoding) => {
+                RpcEncodingConfigWrapper::Deprecated(*encoding)
+            }
+            RpcEncodingConfigWrapper::Current(config) => {
+                RpcEncodingConfigWrapper::Current(config.map(|config| config.into()))
+            }
+        }
+    }
 }
 
 pub trait EncodingConfig {
@@ -204,7 +225,7 @@ pub trait EncodingConfig {
 
 #[derive(Debug, Clone, Copy, Default, PartialEq, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
-pub struct RpcConfirmedBlockConfig {
+pub struct RpcBlockConfig {
     pub encoding: Option<UiTransactionEncoding>,
     pub transaction_details: Option<TransactionDetails>,
     pub rewards: Option<bool>,
@@ -212,7 +233,7 @@ pub struct RpcConfirmedBlockConfig {
     pub commitment: Option<CommitmentConfig>,
 }
 
-impl EncodingConfig for RpcConfirmedBlockConfig {
+impl EncodingConfig for RpcBlockConfig {
     fn new_with_encoding(encoding: &Option<UiTransactionEncoding>) -> Self {
         Self {
             encoding: *encoding,
@@ -221,7 +242,7 @@ impl EncodingConfig for RpcConfirmedBlockConfig {
     }
 }
 
-impl RpcConfirmedBlockConfig {
+impl RpcBlockConfig {
     pub fn rewards_only() -> Self {
         Self {
             transaction_details: Some(TransactionDetails::None),
@@ -238,21 +259,21 @@ impl RpcConfirmedBlockConfig {
     }
 }
 
-impl From<RpcConfirmedBlockConfig> for RpcEncodingConfigWrapper<RpcConfirmedBlockConfig> {
-    fn from(config: RpcConfirmedBlockConfig) -> Self {
+impl From<RpcBlockConfig> for RpcEncodingConfigWrapper<RpcBlockConfig> {
+    fn from(config: RpcBlockConfig) -> Self {
         RpcEncodingConfigWrapper::Current(Some(config))
     }
 }
 
 #[derive(Debug, Clone, Copy, Default, PartialEq, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
-pub struct RpcConfirmedTransactionConfig {
+pub struct RpcTransactionConfig {
     pub encoding: Option<UiTransactionEncoding>,
     #[serde(flatten)]
     pub commitment: Option<CommitmentConfig>,
 }
 
-impl EncodingConfig for RpcConfirmedTransactionConfig {
+impl EncodingConfig for RpcTransactionConfig {
     fn new_with_encoding(encoding: &Option<UiTransactionEncoding>) -> Self {
         Self {
             encoding: *encoding,
@@ -263,16 +284,16 @@ impl EncodingConfig for RpcConfirmedTransactionConfig {
 
 #[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
 #[serde(untagged)]
-pub enum RpcConfirmedBlocksConfigWrapper {
+pub enum RpcBlocksConfigWrapper {
     EndSlotOnly(Option<Slot>),
     CommitmentOnly(Option<CommitmentConfig>),
 }
 
-impl RpcConfirmedBlocksConfigWrapper {
+impl RpcBlocksConfigWrapper {
     pub fn unzip(&self) -> (Option<Slot>, Option<CommitmentConfig>) {
         match &self {
-            RpcConfirmedBlocksConfigWrapper::EndSlotOnly(end_slot) => (*end_slot, None),
-            RpcConfirmedBlocksConfigWrapper::CommitmentOnly(commitment) => (None, *commitment),
+            RpcBlocksConfigWrapper::EndSlotOnly(end_slot) => (*end_slot, None),
+            RpcBlocksConfigWrapper::CommitmentOnly(commitment) => (None, *commitment),
         }
     }
 }
