@@ -1,7 +1,7 @@
 use {
     crate::client_error,
     safecoin_account_decoder::{parse_token::UiTokenAmount, UiAccount},
-    solana_sdk::{
+    safecoin_sdk::{
         clock::{Epoch, Slot, UnixTimestamp},
         fee_calculator::{FeeCalculator, FeeRateGovernor},
         hash::Hash,
@@ -31,7 +31,7 @@ pub struct Response<T> {
 #[serde(rename_all = "camelCase")]
 pub struct RpcBlockCommitment<T> {
     pub commitment: Option<T>,
-    pub total_stake: u64,
+    pub threshold: f64,
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug)]
